
# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: src/mitol/google_sheets_refunds:mitol-django-google-sheets-refunds

from setuptools import setup

setup(**{
    'authors': [
        'MIT Office of Open Learning <mitx-devops@mit.edu>',
    ],
    'classifiers': [
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    'description': 'Library to handle Refund requests using Google Sheets integrations in Django',
    'install_requires': (
        'django<4.0,>=2.2.12',
        'mitol-django-common~=2.5.0',
        'mitol-django-google-sheets~=2.2.6',
        'setuptools',
    ),
    'license': 'BSD 3-Clause License',
    'name': 'mitol-django-google-sheets-refunds',
    'namespace_packages': (
        'mitol',
    ),
    'package_data': {
        'mitol.google_sheets_refunds': (
            'CHANGELOG.md',
            'README.md',
        ),
    },
    'packages': (
        'mitol',
        'mitol.google_sheets_refunds',
        'mitol.google_sheets_refunds.management.commands',
        'mitol.google_sheets_refunds.migrations',
        'mitol.google_sheets_refunds.settings',
    ),
    'version': '0.3.1',
    'zip_safe': True,
})
