# Generated by Django 3.2.13 on 2022-06-29 13:26

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="RefundRequest",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("created_on", models.DateTimeField(auto_now_add=True)),
                ("updated_on", models.DateTimeField(auto_now=True)),
                ("form_response_id", models.IntegerField(db_index=True, unique=True)),
                ("date_completed", models.DateTimeField(blank=True, null=True)),
                ("raw_data", models.CharField(blank=True, max_length=300, null=True)),
            ],
            options={
                "abstract": False,
            },
        ),
    ]
